#[repr(i32)]pub enum ConfigSubscriptionProducts {
Invalid = 0,
LiveDebugging = 1,
}Expand description
ConfigSubscriptionProducts is used to targets specific products for tracking with a ConfigSubscriptionRequest.
Variants
Invalid = 0
LiveDebugging = 1
LIVE_DEBUGGING corresponds to the LIVE_DEBUGING and LIVE_DEBUGGING_SYMBOLDB products.
Implementations
Sourceimpl ConfigSubscriptionProducts
impl ConfigSubscriptionProducts
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ConfigSubscriptionProducts.
Sourcepub fn from_i32(value: i32) -> Option<ConfigSubscriptionProducts>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ConfigSubscriptionProducts>
Converts an i32 to a ConfigSubscriptionProducts, or None if value is not a valid variant.
Sourceimpl ConfigSubscriptionProducts
impl ConfigSubscriptionProducts
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.