ConfigSubscriptionRequest

Struct ConfigSubscriptionRequest 

pub struct ConfigSubscriptionRequest {
    pub runtime_id: String,
    pub action: i32,
    pub products: i32,
}
ConfigSubscriptionRequest is used to manage the state of the stream created using CreateConfigSubscription.

Fields

runtime_id: String

RuntimeID of the client to track or untrack.

action: i32

Action indicates the action to take for the client with the given runtime_id.

products: i32

If action is TRACK, products indicates the set of products for which the client is interested in receiving updates.

Implementations

Source

impl ConfigSubscriptionRequest

pub fn action(&self) -> Action

Returns the enum value of action, or the default if the field is set to an invalid enum value.

pub fn set_action(&mut self, value: Action)

Sets action to the provided enum value.

pub fn products(&self) -> ConfigSubscriptionProducts

Returns the enum value of products, or the default if the field is set to an invalid enum value.

pub fn set_products(&mut self, value: ConfigSubscriptionProducts)

Sets products to the provided enum value.