pub struct ConfigSubscriptionResponse {
pub client: Option<Client>,
pub matched_configs: Vec<String>,
pub target_files: Vec<File>,
}Expand description
ConfigSubscriptionResponse is streamed from CreateConfigSubscription with updates for matching clients and products.
Fields
client: Option<Client>Client is the client that was tracked or untracked.
matched_configs: Vec<String>Matched configs are all configs that were matched for the client given the subscription request.
If a previously reported config is no longer matched, it will not be included in the response.
target_files: Vec<File>Target files are the target files that needs to be sent to the client.