pub struct LatestConfigsRequest {Show 15 fields
pub hostname: String,
pub agent_version: String,
pub current_config_snapshot_version: u64,
pub current_config_root_version: u64,
pub current_director_root_version: u64,
pub products: Vec<String>,
pub new_products: Vec<String>,
pub active_clients: Vec<Client>,
pub backend_client_state: Vec<u8>,
pub has_error: bool,
pub error: String,
pub trace_agent_env: String,
pub org_uuid: String,
pub tags: Vec<String>,
pub agent_uuid: String,
}Fields
hostname: Stringagent_version: Stringcurrent_config_snapshot_version: u64timestamp and snapshot versions move in tandem so they are the same.
current_config_root_version: u64current_director_root_version: u64products: Vec<String>new_products: Vec<String>active_clients: Vec<Client>backend_client_state: Vec<u8>has_error: boolerror: Stringtrace_agent_env: Stringorg_uuid: Stringagent_uuid: StringTrait Implementations
Sourceimpl Clone for LatestConfigsRequest
impl Clone for LatestConfigsRequest
Sourcefn clone(&self) -> LatestConfigsRequest
fn clone(&self) -> LatestConfigsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LatestConfigsRequest
impl Debug for LatestConfigsRequest
Sourceimpl Default for LatestConfigsRequest
impl Default for LatestConfigsRequest
Sourceimpl Message for LatestConfigsRequest
impl Message for LatestConfigsRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for LatestConfigsRequest
impl PartialEq for LatestConfigsRequest
impl StructuralPartialEq for LatestConfigsRequest